==> realestate-supervise-common-1.1.0-20240711.021433-51-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdcbjyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ssywh;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地承包经营权登记信息（耕地等农用地）
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdcbjyq"
)
public class BaTdcbjyq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String dkbm;

    @XmlAttribute
    private String dkmc;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fbfbm;

    @XmlAttribute
    private String fbfqc;

    @XmlAttribute
    private String fbffzr;

    @XmlAttribute
    private String cbfs;

    @XmlAttribute
    private String qqmj;

    @XmlAttribute
    private Date cbqssj;

    @XmlAttribute
    private Date cbjssj;

    @XmlAttribute
    private String cbqx;

    @XmlAttribute
    private String tdsyqxz;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String ydyhfl;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private String sfyjjbnt;

    @XmlAttribute
    private String cbjyqqdfs;

    @XmlAttribute
    private String sfzld;

    @XmlAttribute
    private String sfqqqg;

    @XmlAttribute
    private String bz;

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getDkbm() {
        return dkbm;
    }

    public void setDkbm(String dkbm) {
        this.dkbm = dkbm;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getCbfs() {
        return cbfs;
    }

    public void setCbfs(String cbfs) {
        this.cbfs = cbfs;
    }

    public String getQqmj() {
        return qqmj;
    }

    public void setQqmj(String qqmj) {
        this.qqmj = qqmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public String getCbqx() {
        return cbqx;
    }

    public void setCbqx(String cbqx) {
        this.cbqx = cbqx;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getSfyjjbnt() {
        return sfyjjbnt;
    }

    public void setSfyjjbnt(String sfyjjbnt) {
        this.sfyjjbnt = sfyjjbnt;
    }

    public String getCbjyqqdfs() {
        return cbjyqqdfs;
    }

    public void setCbjyqqdfs(String cbjyqqdfs) {
        this.cbjyqqdfs = cbjyqqdfs;
    }

    public String getSfzld() {
        return sfzld;
    }

    public void setSfzld(String sfzld) {
        this.sfzld = sfzld;
    }

    public String getSfqqqg() {
        return sfqqqg;
    }

    public void setSfqqqg(String sfqqqg) {
        this.sfqqqg = sfqqqg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaTdcbjyq.java <==
package cn.gtmap.realestate.supervise.entity;


import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.sqlx;
import cn.gtmap.realestate.supervise.core.reflect.ssywh;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:huming@gtmap.cn">huming</a>
 * @Date: 2023/12/29 9:07
 * @Description: 土地承包经营权登记信息（耕地等农用地）
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_tdcbjyq"
)
public class BaTdcbjyq implements Serializable {

    @XmlAttribute
    @Id
    @id
    private String id;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    @Nullable
    @ywh
    private String ywh;

    @XmlAttribute
    @ssywh
    private String ssywh;

    @XmlAttribute
    private String dkbm;

    @XmlAttribute
    private String dkmc;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String djlx;

    @XmlAttribute
    private String djyy;

    @XmlAttribute
    private String fbfbm;

    @XmlAttribute
    private String fbfqc;

    @XmlAttribute
    private String fbffzr;

    @XmlAttribute
    private String cbfs;

    @XmlAttribute
    private String qqmj;

    @XmlAttribute
    private Date cbqssj;

    @XmlAttribute
    private Date cbjssj;

    @XmlAttribute
    private String cbqx;

    @XmlAttribute
    private String tdsyqxz;

    @XmlAttribute
    private String yt;

    @XmlAttribute
    private String ydyhfl;

    @XmlAttribute
    private String htdm;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    private String qxdm;

    @XmlAttribute
    private String djjg;

    @XmlAttribute
    private String dbr;

    @XmlAttribute
    private Date djsj;

    @XmlAttribute
    private String fj;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private String sfyjjbnt;

    @XmlAttribute
    private String cbjyqqdfs;

    @XmlAttribute
    private String sfzld;

    @XmlAttribute
    private String sfqqqg;

    @XmlAttribute
    private String bz;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYsdm() {
        return ysdm;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getSsywh() {
        return ssywh;
    }

    public void setSsywh(String ssywh) {
        this.ssywh = ssywh;
    }

    public String getDkbm() {
        return dkbm;
    }

    public void setDkbm(String dkbm) {
        this.dkbm = dkbm;
    }

    public String getDkmc() {
        return dkmc;
    }

    public void setDkmc(String dkmc) {
        this.dkmc = dkmc;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getDjlx() {
        return djlx;
    }

    public void setDjlx(String djlx) {
        this.djlx = djlx;
    }

    public String getDjyy() {
        return djyy;
    }

    public void setDjyy(String djyy) {
        this.djyy = djyy;
    }

    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getFbfqc() {
        return fbfqc;
    }

    public void setFbfqc(String fbfqc) {
        this.fbfqc = fbfqc;
    }

    public String getFbffzr() {
        return fbffzr;
    }

    public void setFbffzr(String fbffzr) {
        this.fbffzr = fbffzr;
    }

    public String getCbfs() {
        return cbfs;
    }

    public void setCbfs(String cbfs) {
        this.cbfs = cbfs;
    }

    public String getQqmj() {
        return qqmj;
    }

    public void setQqmj(String qqmj) {
        this.qqmj = qqmj;
    }

    public Date getCbqssj() {
        return cbqssj;
    }

    public void setCbqssj(Date cbqssj) {
        this.cbqssj = cbqssj;
    }

    public Date getCbjssj() {
        return cbjssj;
    }

    public void setCbjssj(Date cbjssj) {
        this.cbjssj = cbjssj;
    }

    public String getCbqx() {
        return cbqx;
    }

    public void setCbqx(String cbqx) {
        this.cbqx = cbqx;
    }

    public String getTdsyqxz() {
        return tdsyqxz;
    }

    public void setTdsyqxz(String tdsyqxz) {
        this.tdsyqxz = tdsyqxz;
    }

    public String getYt() {
        return yt;
    }

    public void setYt(String yt) {
        this.yt = yt;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getHtdm() {
        return htdm;
    }

    public void setHtdm(String htdm) {
        this.htdm = htdm;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

    public String getDjjg() {
        return djjg;
    }

    public void setDjjg(String djjg) {
        this.djjg = djjg;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public String getSfyjjbnt() {
        return sfyjjbnt;
    }

    public void setSfyjjbnt(String sfyjjbnt) {
        this.sfyjjbnt = sfyjjbnt;
    }

    public String getCbjyqqdfs() {
        return cbjyqqdfs;
    }

    public void setCbjyqqdfs(String cbjyqqdfs) {
        this.cbjyqqdfs = cbjyqqdfs;
    }

    public String getSfzld() {
        return sfzld;
    }

    public void setSfzld(String sfzld) {
        this.sfzld = sfzld;
    }

    public String getSfqqqg() {
        return sfqqqg;
    }

    public void setSfqqqg(String sfqqqg) {
        this.sfqqqg = sfqqqg;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }
}
